@@ -1177,7 +1177,7 @@ bool Style::parsePolygons(SubFile *file, SubFile::Handle &hdl,
 
 		if (!parsePolygon(file, hdl, section, info, type))
 			qWarning("%s: %x: broken polygon style",
-			  qPrintable(file->fileName()), type);
+			  qUtf8Printable(file->fileName()), type);
 	}
 
 	return true;
@@ -1201,8 +1201,8 @@ bool Style::parseLines(SubFile *file, SubFile::Handle &hdl,
 		  ? 0x10000 | (info.type << 8) | info.subtype : (info.type << 8);
 
 		if (!parseLine(file, hdl, section, info, type))
-			qWarning("%s: %x: broken line style", qPrintable(file->fileName()),
-			  type);
+			qWarning("%s: %x: broken line style",
+			  qUtf8Printable(file->fileName()), type);
 	}
 
 	return true;
@@ -1227,8 +1227,8 @@ bool Style::parsePoints(SubFile *file, SubFile::Handle &hdl,
 		  : (info.type << 8) | info.subtype;
 
 		if (!parsePoint(file, hdl, section, info, type))
-			qWarning("%s: %x: broken point style", qPrintable(file->fileName()),
-			  type);
+			qWarning("%s: %x: broken point style",
+			  qUtf8Printable(file->fileName()), type);
 	}
 
 	return true;
@@ -1268,9 +1268,9 @@ bool Style::parseDrawOrder(SubFile *file, SubFile::Handle &hdl,
 	return true;
 }
 
-bool Style::parseTYPFile(QFile *file, SubFile *typ)
+bool Style::parseTYPFile(SubFile *typ)
 {
-	SubFile::Handle hdl(file, typ);
+	SubFile::Handle hdl(typ);
 	Section points, lines, polygons, order;
 	quint16 tmp16, codepage;
 
@@ -1304,14 +1304,14 @@ bool Style::parseTYPFile(QFile *file, SubFile *typ)
 	  && parsePolygons(typ, hdl, polygons)
 	  && parseDrawOrder(typ, hdl, order))) {
 		qWarning("%s: Invalid TYP file, using default style",
-		  qPrintable(typ->fileName()));
+		  qUtf8Printable(typ->fileName()));
 		return false;
 	}
 
 	return true;
 }
 
-Style::Style(QFile *file, qreal ratio, SubFile *typ)
+Style::Style(qreal ratio, SubFile *typ)
 {
 	_large = pixelSizeFont(16);
 	_normal = pixelSizeFont(14);
@@ -1326,7 +1326,7 @@ Style::Style(QFile *file, qreal ratio, SubFile *typ)
 	defaultPointStyle(ratio);
 
 	if (typ)
-		parseTYPFile(file, typ);
+		parseTYPFile(typ);
 }
 
 const Style::Line &Style::line(quint32 type) const
