@@ -104,7 +104,7 @@ public:
 	};
 
 
-	Style(QFile *file, qreal ratio, SubFile *typ = 0);
+	Style(qreal ratio, SubFile *typ = 0);
 
 	const Line &line(quint32 type) const;
 	const Polygon &polygon(quint32 type) const;
@@ -134,6 +134,8 @@ public:
 	  {return (type == TYPE(0x16) || type == 0x10a03);}
 	static bool isSpot(quint32 type)
 	  {return (type == TYPE(0x62) || type == TYPE(0x63));}
+	static bool isSummit(quint32 type)
+	  {return (type == 0x6616);}
 	static bool isMajorRoad(quint32 type)
 	  {return (type <= TYPE(0x04));}
 	static bool isCountry(quint32 type)
@@ -171,7 +173,7 @@ private:
 		bool extended;
 	};
 
-	bool parseTYPFile(QFile *file, SubFile *typ);
+	bool parseTYPFile(SubFile *typ);
 	bool parsePoints(SubFile *file, SubFile::Handle &hdl,
 	  const Section &section);
 	bool parsePoint(SubFile *file, SubFile::Handle &hdl,
